@@ -1,4 +1,3 @@
-/* $Xorg: FSListCats.c,v 1.4 2001/02/09 02:03:25 xorgcvs Exp $ */
 /*
  * Copyright 1990 Network Computing Devices;
  * Portions Copyright 1987 by Digital Equipment Corporation
@@ -23,7 +22,7 @@
  * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS 
  * SOFTWARE.
  */
-/* $XFree86: xc/lib/FS/FSListCats.c,v 1.7 2003/12/22 17:48:02 tsi Exp $ */
+/* $XFree86: xc/lib/FS/FSListCats.c,v 1.8 2005/03/23 03:11:23 dawes Exp $ */
 
 /*
 
@@ -53,12 +52,8 @@ in this Software without prior written authorization from The Open Group.
 
 #include	"FSlibint.h"
 
-char      **
-FSListCatalogues(svr, pattern, maxNames, actualCount)
-    FSServer   *svr;
-    char       *pattern;
-    int         maxNames;
-    int        *actualCount;
+char **
+FSListCatalogues(FSServer *svr, char *pattern, int maxNames, int *actualCount)
 {
     long        nbytes;
     int         i,
@@ -118,8 +113,8 @@ FSListCatalogues(svr, pattern, maxNames, actualCount)
 
 }
 
-int FSFreeCatalogues(list)
-    char      **list;
+int
+FSFreeCatalogues(char **list)
 {
     if (list) {
 	FSfree(list[0] - 1);
